==> spip_4.1.1+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_nb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=nb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'bare for fremtidige artikler (ingen handling mot databasen).',
	'bouton_radio_articles_tous' => 'for alle artikler uten unntak.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'for alle artikler, untatt de med avslåtte forum.',
	'bouton_radio_moderation_priori' => 'Forhåndsmoderasjon (
 bidrag vil bare bli vist etter å ha blitt godkjent av
 administratorer).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderasjon etter påmelding', # MODIF
	'bouton_radio_modere_posteriori' => 'endring i etterkant', # MODIF
	'bouton_radio_modere_priori' => 'endring på forhånd', # MODIF
	'bouton_radio_publication_immediate' => 'Umiddelbar publisering av meldinger
 (bidrag vil bli vist det øyeblikket de er sendt, deretter kan
 administratorer slette dem).',

	// F
	'form_pet_message_commentaire' => 'Har du en melding eller kommentar?',
	'forum_acces_refuse' => 'Du har ikke tilgang til forumene lengre.',
	'forum_attention_dix_caracteres' => '<b>Advarsel!</b> meldingen er kortere enn ti tegn.', # MODIF
	'forum_attention_trois_caracteres' => '<b>Advarsel!</b> emnet er kortere enn tre tegn.', # MODIF
	'forum_attention_trop_caracteres' => '<b>Advarsel !</b> meldinger er for lang (@compte@ tegn) : for at den skal kunne lagres må den ikke inneholde mer enn @max@ tegn.', # MODIF
	'forum_avez_selectionne' => 'Du har valgt:',
	'forum_cliquer_retour' => 'Klikk  <a href=\'@retour_forum@\'>her</a> for å fortsette.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Dette forumet er overvåket: ditt innlegg vil vises etter å ha blitt sjekket av en administrator.', # MODIF
	'forum_lien_hyper' => '<b>Lenke</b> (valgfritt)', # MODIF
	'forum_message_definitif' => 'Siste melding: send til vev-sted',
	'forum_message_trop_long' => 'Meldingen er for lang. Maksimal lengde er 20000 tegn.', # MODIF
	'forum_ne_repondez_pas' => 'Ikke svar på denne e-posten, men i forumet på følgende adresse:', # MODIF
	'forum_page_url' => '(Dersom meldingen din refererer til en side på veven vennligst legg inn tittel og adressen til siden nedenfor).',
	'forum_poste_par' => 'Melding kommet @parauteur@ til din artikkel "@titre@".', # MODIF
	'forum_qui_etes_vous' => '<b>Hvem er du?</b> (valgfritt)', # MODIF
	'forum_texte' => 'Meldingstekst:', # MODIF
	'forum_titre' => 'Emne:', # MODIF
	'forum_url' => 'URI:', # MODIF
	'forum_valider' => 'Bekreft dette valget',
	'forum_voir_avant' => 'Forhåndsvis melding først ', # MODIF
	'forum_votre_email' => 'Epostadresse:', # MODIF
	'forum_votre_nom' => 'Navn (eller kallenavn):', # MODIF
	'forum_vous_enregistrer' => 'Før man kan delta in
  dette forumet må man registrere seg.
  Vennligst logg inn.
  Dersom du ikke har registrert deg må du',
	'forum_vous_inscrire' => 'registrer.',

	// I
	'icone_suivi_forums' => 'Behandle forum',
	'icone_supprimer_message' => 'Slett melding',
	'icone_valider_message' => 'Bekreft denne meldingen',

	// L
	'lien_reponse_article' => 'Svar på artikkelen',
	'lien_reponse_rubrique' => 'Svar på seksjonen',

	// O
	'onglet_messages_internes' => 'Interne meldinger',
	'onglet_messages_publics' => 'Offentlige meldinger',
	'onglet_messages_vide' => 'Meldinger uten tekst',

	// T
	'titre_cadre_forum_interne' => 'Internforum',
	'titre_forum' => 'Internforum', # MODIF
	'titre_forum_suivi' => 'Oppfølging av forum',
	'titre_page_forum_suivi' => 'Oppfølging av forum'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_nb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=nb
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'bare for fremtidige artikler (ingen handling mot databasen).',
	'bouton_radio_articles_tous' => 'for alle artikler uten unntak.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'for alle artikler, untatt de med avslåtte forum.',
	'bouton_radio_moderation_priori' => 'Forhåndsmoderasjon (
 bidrag vil bare bli vist etter å ha blitt godkjent av
 administratorer).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderasjon etter påmelding', # MODIF
	'bouton_radio_modere_posteriori' => 'endring i etterkant', # MODIF
	'bouton_radio_modere_priori' => 'endring på forhånd', # MODIF
	'bouton_radio_publication_immediate' => 'Umiddelbar publisering av meldinger
 (bidrag vil bli vist det øyeblikket de er sendt, deretter kan
 administratorer slette dem).',

	// F
	'form_pet_message_commentaire' => 'Har du en melding eller kommentar?',
	'forum_acces_refuse' => 'Du har ikke tilgang til forumene lengre.',
	'forum_attention_dix_caracteres' => '<b>Advarsel!</b> meldingen er kortere enn ti tegn.', # MODIF
	'forum_attention_trois_caracteres' => '<b>Advarsel!</b> emnet er kortere enn tre tegn.', # MODIF
	'forum_attention_trop_caracteres' => '<b>Advarsel !</b> meldinger er for lang (@compte@ tegn) : for at den skal kunne lagres må den ikke inneholde mer enn @max@ tegn.', # MODIF
	'forum_avez_selectionne' => 'Du har valgt:',
	'forum_cliquer_retour' => 'Klikk  <a href=\'@retour_forum@\'>her</a> for å fortsette.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Dette forumet er overvåket: ditt innlegg vil vises etter å ha blitt sjekket av en administrator.', # MODIF
	'forum_lien_hyper' => '<b>Lenke</b> (valgfritt)', # MODIF
	'forum_message_definitif' => 'Siste melding: send til vev-sted',
	'forum_message_trop_long' => 'Meldingen er for lang. Maksimal lengde er 20000 tegn.', # MODIF
	'forum_ne_repondez_pas' => 'Ikke svar på denne e-posten, men i forumet på følgende adresse:', # MODIF
	'forum_page_url' => '(Dersom meldingen din refererer til en side på veven vennligst legg inn tittel og adressen til siden nedenfor).',
	'forum_poste_par' => 'Melding kommet @parauteur@ til din artikkel "@titre@".', # MODIF
	'forum_qui_etes_vous' => '<b>Hvem er du?</b> (valgfritt)', # MODIF
	'forum_texte' => 'Meldingstekst:', # MODIF
	'forum_titre' => 'Emne:', # MODIF
	'forum_url' => 'URI:', # MODIF
	'forum_valider' => 'Bekreft dette valget',
	'forum_voir_avant' => 'Forhåndsvis melding først ', # MODIF
	'forum_votre_email' => 'Epostadresse:', # MODIF
	'forum_votre_nom' => 'Navn (eller kallenavn):', # MODIF
	'forum_vous_enregistrer' => 'Før man kan delta in
  dette forumet må man registrere seg.
  Vennligst logg inn.
  Dersom du ikke har registrert deg må du',
	'forum_vous_inscrire' => 'registrer.',

	// I
	'icone_suivi_forums' => 'Behandle forum',
	'icone_supprimer_message' => 'Slett melding',
	'icone_valider_message' => 'Bekreft denne meldingen',

	// L
	'lien_reponse_article' => 'Svar på artikkelen',
	'lien_reponse_rubrique' => 'Svar på seksjonen',

	// O
	'onglet_messages_internes' => 'Interne meldinger',
	'onglet_messages_publics' => 'Offentlige meldinger',
	'onglet_messages_vide' => 'Meldinger uten tekst',

	// T
	'titre_cadre_forum_interne' => 'Internforum',
	'titre_forum' => 'Internforum', # MODIF
	'titre_forum_suivi' => 'Oppfølging av forum',
	'titre_page_forum_suivi' => 'Oppfølging av forum',
];
